@@ -1,13 +1,21 @@
 <?php
 
-   // include compatibility plugin
-   //
-   if (defined('SM_PATH'))
-      include_once(SM_PATH . 'plugins/compatibility/functions.php');
-   else if (file_exists('../plugins/compatibility/functions.php'))
-      include_once('../plugins/compatibility/functions.php');
-   else if (file_exists('./plugins/compatibility/functions.php'))
-      include_once('./plugins/compatibility/functions.php');
+
+/**
+  * Initialize this plugin (load config values)
+  *
+  * @return boolean FALSE if no configuration file could be loaded, TRUE otherwise
+  *
+  */
+function mark_read_init() {
+
+   if (!@include_once (SM_PATH . 'plugins/mark_read/config.php'))
+      if (!@include_once (SM_PATH . 'plugins/mark_read/config.sample.php'))
+         return FALSE;
+
+   return TRUE;
+
+}
 
 // Display mark_read links on target folders
 //
@@ -20,7 +28,7 @@ function mark_read_show_link_do($parms) {
 	  $default_user_mark_read_brackets;
 
    include_once(SM_PATH . 'functions/i18n.php');
-   bindtextdomain('mark_read', SM_PATH . 'plugins/mark_read/locale');
+   bindtextdomain('mark_read', SM_PATH . 'locale');
    textdomain('mark_read');
    
    $numMessages = $parms[0];
@@ -28,10 +36,7 @@ function mark_read_show_link_do($parms) {
    $imapConnection = $parms[2];
 
 
-   if (compatibility_check_sm_version(1, 3))
-      include_once (SM_PATH . 'plugins/mark_read/config.php');
-   else
-      include_once ('../plugins/mark_read/config.php');
+   mark_read_init();
 
 
    // grab preferences
@@ -146,7 +151,7 @@ function mark_read_do_mark_all_read() {
           $default_user_mark_read_brackets;
 
   include_once(SM_PATH . 'functions/i18n.php');
-  bindtextdomain('mark_read', SM_PATH . 'plugins/mark_read/locale');
+  bindtextdomain('mark_read', SM_PATH . 'locale');
   textdomain('mark_read');
 
 
@@ -177,20 +182,20 @@ function mark_read_show_options_do() {
           $default_user_mark_read_brackets;
 
   include_once(SM_PATH . 'functions/i18n.php');
-  bindtextdomain('mark_read', SM_PATH . 'plugins/mark_read/locale');
+  bindtextdomain('mark_read', SM_PATH . 'locale');
   textdomain('mark_read');
 
    // grab new settings if user had just pressed Save
    //
    global $mark_read_form;
-   compatibility_sqextractGlobalVar('mark_read_form');
+   sqGetGlobalVar('mark_read_form', $mark_read_form);
    if (isset($mark_read_form) && $mark_read_form)
    {
 
       // get folders that should get a mark_read link
       //
       global $mark_read_show_link;
-      compatibility_sqextractGlobalVar('mark_read_show_link');
+      sqGetGlobalVar('mark_read_show_link', $mark_read_show_link);
       $allFolders = '';
       if (isset($mark_read_show_link))
          foreach ($mark_read_show_link as $folder)
@@ -202,7 +207,7 @@ function mark_read_show_options_do() {
       // get display options from the form
       //
       global $mark_read_display_is_short;
-      compatibility_sqextractGlobalVar('mark_read_display_is_short');
+      sqGetGlobalVar('mark_read_display_is_short', $mark_read_display_is_short);
       if( isset($mark_read_display_is_short) ) {
          setPref($data_dir, $username, 'mark_read_display_is_short', $mark_read_display_is_short);
       } else {
@@ -210,7 +215,7 @@ function mark_read_show_options_do() {
       }
 
       global $user_mark_read_brackets;
-      compatibility_sqextractGlobalVar('user_mark_read_brackets');
+      sqGetGlobalVar('user_mark_read_brackets', $user_mark_read_brackets);
       if( isset($user_mark_read_brackets) ) {
          setPref($data_dir, $username, 'user_mark_read_brackets', $user_mark_read_brackets);
       } else {
@@ -218,7 +223,7 @@ function mark_read_show_options_do() {
       }
 
       global $mark_read_display_upper;
-      compatibility_sqextractGlobalVar('mark_read_display_upper');
+      sqGetGlobalVar('mark_read_display_upper', $mark_read_display_upper);
       if( isset($mark_read_display_upper) ) {
          setPref($data_dir, $username, 'mark_read_display_upper', $mark_read_display_upper);
       } else {
@@ -226,7 +231,7 @@ function mark_read_show_options_do() {
       }
 
       global $user_mark_read_separator;
-      compatibility_sqextractGlobalVar('user_mark_read_separator');
+      sqGetGlobalVar('user_mark_read_separator', $user_mark_read_separator);
       if( isset($user_mark_read_separator) ) {
          setPref($data_dir, $username, 'user_mark_read_separator', $user_mark_read_separator);
       } else {
@@ -234,7 +239,7 @@ function mark_read_show_options_do() {
       }
 
       global $mark_read_display;
-      compatibility_sqextractGlobalVar('mark_read_display');
+      sqGetGlobalVar('mark_read_display', $mark_read_display);
       if( isset($mark_read_display) ) {
          setPref($data_dir, $username, 'mark_read_display', $mark_read_display);
       } else {
@@ -242,7 +247,7 @@ function mark_read_show_options_do() {
       }
 
       global $mark_read_displayall;
-      compatibility_sqextractGlobalVar('mark_read_displayall');
+      sqGetGlobalVar('mark_read_displayall', $mark_read_displayall);
       if( isset($mark_read_displayall) ) {
          setPref($data_dir, $username, 'mark_read_displayall', $mark_read_displayall);
       } else {
@@ -252,10 +257,7 @@ function mark_read_show_options_do() {
    }
 
 
-   if (compatibility_check_sm_version(1, 3))
-      include_once (SM_PATH . 'plugins/mark_read/config.php');
-   else
-      include_once ('../plugins/mark_read/config.php');
+   mark_read_init();
 
 
    // grab preferences
@@ -283,24 +285,24 @@ function mark_read_show_options_do() {
    if ($user_mark_read_link)
    {
 
-      echo '<FORM METHOD="POST" NAME="mark_read_links_form">'
-         . '<input type="hidden" value="1" name="mark_read_form">'
-         . '<TABLE border=4 WIDTH="70%" COLS="1" ALIGN="CENTER" cellpadding="4" '
+      echo "\n" . '<form method="post" name="mark_read_links_form">'
+         . "\n" . '<input type="hidden" value="1" name="mark_read_form">'
+         . "\n" . '<table border="0" width="70%" cols="1" align="center" cellpadding="4" '
          . 'cellspacing="0" border="0">'
-         . "<tr><td bgcolor=\"$color[4]\">&nbsp;</td></tr>\n"
-         . "<TR><TD BGCOLOR=\"$color[9]\" ALIGN=CENTER><B>"
+//         . "<tr><td bgcolor=\"$color[4]\">&nbsp;</td></tr>\n"
+         . "<tr><td bgcolor=\"$color[9]\" align=\"center\"><B>"
          . _("Mark Read Link")
-         . '</B></TD></TR>'
-         . "<TR><TD BGCOLOR=\"$color[0]\" ALIGN=CENTER>"
+         . '</B></td></tr>'
+         . "<tr><td bgcolor=\"$color[0]\" align=\"center\">"
          . _("Select all Folders, which you want to appear with a mark as read-/unread-link:")
-         . '</TD></TR>'
-         . "<TR><TD BGCOLOR=\"$color[0]\" ALIGN=CENTER>";
+         . '</td></tr>'
+         . "<tr><td bgcolor=\"$color[0]\" align=\"center\">";
       if ($user_mark_read_link)
       {
          global $boxes, $trash_folder;
          $specialFolders = array();
-         echo '<TABLE WIDTH="100%" BORDER="0"><TR><TD width="60%" align="right">'
-            . '<SELECT NAME="mark_read_show_link[]" multiple size="15">';
+         echo '<table width="100%" border="0"><tr><td width="60%" align="right">'
+            . '<select name="mark_read_show_link[]" multiple size="15">';
          for ($i = 0; $i < count($boxes); $i++) 
          {
       //      if (strtolower($boxes[$i]['unformatted']) != $trash_folder)
@@ -309,10 +311,10 @@ function mark_read_show_options_do() {
                $box2 = str_replace(' ','&nbsp;',imap_utf7_decode_local(
                                                 $boxes[$i]['unformatted-disp']));
                if (strtolower($box) != 'inbox.trash') 
-                  echo '<OPTION VALUE="' . $box . '"'
+                  echo '<option value="' . $box . '"'
                      . (isset($mark_read_show_link) 
                         && in_array($box, $mark_read_show_link)
-                        ? ' SELECTED' : '') . '>' . $box2 . "\n";
+                        ? ' selected' : '') . '>' . $box2 . "\n";
 
                // get special folder list for use below
                //
@@ -322,7 +324,7 @@ function mark_read_show_options_do() {
       //      }
          }
 
-         echo '</SELECT></TD><TD valign="bottom">'
+         echo '</select></td><td valign="bottom">'
             . '&nbsp;&nbsp;<a href="#" onClick="list=document.mark_read_links_form.elements[1]; for (i=0; i<list.length; i++) {if (';
          $first = true;
          foreach ($specialFolders as $specialFolder)
@@ -332,7 +334,7 @@ function mark_read_show_options_do() {
             echo 'list.options[i].text==\'' . $specialFolder . '\'';
          }
          echo ') { if (list.options[i].selected) list.options[i].selected=false; else list.options[i].selected=true; } } return false">'._("Toggle Special Folders").'</a><br><br>'
-            . '&nbsp;&nbsp;<a href="#" onClick="list=document.mark_read_links_form.elements[1]; for (i=0; i<list.length; i++) {if (list.options[i].selected) list.options[i].selected=false; else list.options[i].selected=true; } return false">'._("Toggle All").'</a></TD></TR></TABLE>';
+            . '&nbsp;&nbsp;<a href="#" onClick="list=document.mark_read_links_form.elements[1]; for (i=0; i<list.length; i++) {if (list.options[i].selected) list.options[i].selected=false; else list.options[i].selected=true; } return false">'._("Toggle All").'</a></td></tr></table>';
          
          echo _("Display links") .': <select name="mark_read_display" size="1">'.
                '<option '.($mark_read_display==0?'selected ':'').'value="0">'. _("none") .'</option>'.
@@ -341,13 +343,13 @@ function mark_read_show_options_do() {
                '<option '.($mark_read_display==3?'selected ':'').'value="3">'. _("read/unread") .'</option>'.
                '</select>' ;
 
-         echo '&nbsp;&nbsp;<input type="radio" name="mark_read_display_upper" value="1" id="mark_read_upper" ' . ($mark_read_display_upper==1?'checked ':' ') . '>';
-         echo _("upper");
-         echo '<input type="radio" name="mark_read_display_upper" value="0" id="mark_read_display_upper" ' . ($mark_read_display_upper==0?'checked ':' ') . '>'; 
-         echo _("lower");
+         echo '&nbsp;&nbsp;<input type="radio" name="mark_read_display_upper" id="mark_read_display_upper" value="1" id="mark_read_upper" ' . ($mark_read_display_upper==1?'checked ':' ') . '> <label for="mark_read_display_upper">';
+         echo _("upper") . '</label>';
+         echo '<input type="radio" name="mark_read_display_upper" id="mark_read_display_upper" value="0" id="mark_read_display_upper" ' . ($mark_read_display_upper==0?'checked ':' ') . '> <label for="mark_read_display_upper">'; 
+         echo _("lower") . '</label>';
 
-         echo '&nbsp;&nbsp;<input type="checkbox" name="mark_read_display_is_short" value="1" '.($mark_read_display_is_short==1?'checked="checked"':'').' /> '.
-               _("shortened")."<BR \>";
+         echo '&nbsp;&nbsp;<input type="checkbox" name="mark_read_display_is_short" id="mark_read_display_is_short" value="1" '.($mark_read_display_is_short==1?'checked="checked"':'').' /> <label for="mark_read_display_is_short">'.
+               _("shortened")."</label><br />";
 
          echo _("brackets") .': <select name="user_mark_read_brackets" size="1">'.
                '<option '.($user_mark_read_brackets==0?'selected ':'').'value="0">'. _("none") .'</option>'.
@@ -369,18 +371,18 @@ function mark_read_show_options_do() {
                '<option '.($user_mark_read_separator==7?'selected ':'').'value="7">'."+".'</option>'.
                '<option '.($user_mark_read_separator==8?'selected ':'').'value="8">'." ".'</option>'.
                '</select>' ;
-         echo "<BR \>";
+         echo "<br />";
 
          # $mark_read_displayall may be unset, so initialize it with the default value
          if( !isset($mark_read_displayall) ) $mark_read_displayall = $default_mark_read_displayall;
 
-         echo '<input type="checkbox" name="mark_read_displayall" value="1" '.($mark_read_displayall==1?'checked="checked"':'').' /> '.
-               _("Display 'mark all folders' link below the folder list");
+         echo '<input type="checkbox" name="mark_read_displayall" id="mark_read_displayall" value="1" '.($mark_read_displayall==1?'checked="checked"':'').' /> <label for="mark_read_displayall">'.
+               _("Display 'mark all folders' link below the folder list") . '</label>';
       }
-      echo '</TD></TR><TR><TD BGCOLOR="' . $color[0] 
+      echo '</td></tr><tr><td bgcolor="' . $color[0] 
          . '" align="right"><input type="submit" value="' 
          . _("Save") . '">'
-         . '</TD></TR></TABLE></FORM>';
+         . '</td></tr></table></form>';
 
    }
 
